{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  boot.loader.grub.device = "/dev/sdd";

  networking.hostName = "Fazo-PC"; # Define your hostname.
  networking.hostId = "6bc261fc";

  i18n = {
    consoleFont = "lat9w-16";
    consoleKeyMap = "it";
    defaultLocale = "en_US.UTF-8";
  };

  nixpkgs.config.allowUnfree = true;
  environment.systemPackages = with pkgs; [
    tmux vim sxhkd w3m rxvt_unicode chromium htop atom git zsh dmenu gnupg ranger syncthing
  ];

  fonts = {
    enableFontDir = true;
    enableGhostscriptFonts = true;
    fonts = with pkgs; [
      gohufont
    ];
  };

  services.openssh = {
    enable = true;
    permitRootLogin = "no";
    passwordAuthentication = false;
  };

  services.xserver = {
    enable = true;
    videoDrivers = [ "nvidia" ];
    layout = "it";
    windowManager.bspwm.enable = true;
  };

  users.extraUsers.fazo = {
    isNormalUser = true;
    extraGroups = [ "wheel" ];
    uid = 1000;
    shell = "/run/current-system/sw/bin/zsh";
    openssh.authorizedKeys.keys = [ ];
  };

}
